#ifndef Mariner10Camera_h
#define Mariner10Camera_h
/**
 * @file
 * $Revision: 1.5 $
 * $Date: 2010/06/29 18:16:39 $
 *
 *   Unless noted otherwise, the portions of Isis written by the USGS are public
 *   domain. See individual third-party library and package descriptions for
 *   intellectual property information,user agreements, and related information.
 *
 *   Although Isis has been used by the USGS, no warranty, expressed or implied,
 *   is made by the USGS as to the accuracy and functioning of such software
 *   and related material nor shall the fact of distribution constitute any such
 *   warranty, and no responsibility is assumed by the USGS in connection
 *   therewith.
 *
 *   For additional information, launch
 *   $ISISROOT/doc//documents/Disclaimers/Disclaimers.html in a browser or see
 *   the Privacy &amp; Disclaimers page on the Isis website,
 *   http://isis.astrogeology.usgs.gov, and the USGS privacy and disclaimers on
 *   http://www.usgs.gov/privacy.html.
 */

#include "FramingCamera.h"

namespace Isis {
  /**
   * @brief Mariner10 Camera Model
   *
   * This is the camera model for both mariner10, both cameras A (wide angle)
   * and B (narrow angle).
   *
   * @ingroup SpiceInstrumentsAndCameras
   * @ingroup Mariner10
   *
   * @author 2009-04-13 Tracie Sucharski
   *
   * @internal
   *   @history 2009-12-18 Tracie Sucharski - Changed inheritance from Camera to
   *                          FramingCamera.
   *   @history 2010-02-22 Tracie Sucharski - Preface naif includes with /naif.
   *   @history 2010-03-04 Tracie Sucharski - Removed couts.
   *   @history 2010-03-04 Tracie Sucharski - Added throw when creation of
   *                          ReseauDistortion fails.
   *   @history 2011-01-14 Travis Addair - Added new CK/SPK accessor methods,
   *                          pure virtual in Camera, implemented in mission
   *                          specific cameras.
   *   @history 2011-02-09 Steven Lambright - Major changes to camera classes.
   *   @history 2011-05-03 Jeannie Walldren - Added ShutterOpenCloseTimes()
   *                          method. Updated unitTest to test for new methods.
   *                          Updated documentation. Added Isis Disclaimer to
   *                          files. Added NAIF error check to constructor.
   *   @history 2012-07-06 Debbie A. Cook, Updated Spice members to be more compliant with Isis 
   *                          coding standards. References #972.
   *  
   */
  class Mariner10Camera : public FramingCamera {
    public:
      Mariner10Camera(Cube &cube);
      //! Destroys the Mariner10Camera Object
      ~Mariner10Camera() {};
      virtual std::pair <iTime, iTime> ShutterOpenCloseTimes(double time, 
                                                             double exposureDuration);

      /**
       * CK frame ID -  - Instrument Code from spacit run on CK
       *  
       * @return @b int The appropriate instrument code for the "Camera-matrix" 
       *         Kernel Frame ID
       */
      virtual int CkFrameId() const { return (-76000); }

      /** 
       * CK Reference ID - J2000
       * 
       * @return @b int The appropriate instrument code for the "Camera-matrix"
       *         Kernel Reference ID
       */
      virtual int CkReferenceId() const { return (1); }

      /** 
       *  SPK Reference ID - J2000
       *  
       * @return @b int The appropriate instrument code for the Spacecraft 
       *         Kernel Reference ID
       */
      virtual int SpkReferenceId() const { return (1); }
  };
};
#endif
